Scrapple
========

[![Build Status](https://travis-ci.org/scrappleapp/scrapple.svg?branch=master)](https://travis-ci.org/scrappleapp/scrapple)

[Scrapple](http://scrappleapp.github.io/scrapple) is a framework for creating web scrapers and web crawlers according to a key-value based configuration file. It provides a command line interface to run the script on a given JSON-based configuration input, as well as a web interface to provide the necessary input.

You can install Scrapple by using

```
$ sudo apt-get install libxml2-dev libxslt-dev python-dev lib32z1-dev
$ pip install scrapple
```

You can read the complete documentation [here](http://scrapple.rtfd.org).
